-- Ensure the json module is available
local json = require("json")

local M = {}
M.dependencies = {'career_career'}

local playbook = {}
local fileName = "playbook.json"

local function addMissionPlayedEntry(missionId, stars)
  local e = {
    missionId = missionId,
    stars = stars
  }
  table.insert(playbook, e)
end

local function loadDataFromFile()
  local saveSlot, savePath = career_saveSystem.getCurrentSaveSlot()
  if not saveSlot then return end
  playbook = (savePath and jsonReadFile(savePath .. "/career/"..fileName)) or {}
end

local function onExtensionLoaded()
  if not career_career.isActive() then return false end
  loadDataFromFile()
end

local function onCareerActive(active)
  loadDataFromFile()
end

-- Reset stars to false for all missions
local function resetStarsToFalse()
  for _, entry in ipairs(playbook) do
    for starKey, _ in pairs(entry.stars) do
      entry.stars[starKey] = false
    end
 end
end

-- this should only be loaded when the career is active
local function onSaveCurrentSaveSlot(currentSavePath)
  resetStarsToFalse()
  jsonWriteFile(currentSavePath .. "/career/"..fileName, playbook, true)
end

M.onExtensionLoaded = onExtensionLoaded
M.onCareerActive = onCareerActive
M.onSaveCurrentSaveSlot = onSaveCurrentSaveSlot
M.onClientStartMission = onClientStartMission
M.addMissionPlayedEntry = addMissionPlayedEntry

return M
